@@ -22,7 +22,6 @@ newcode.r = resolve(code = newcode.t)
 
 summary(newcode.r)
 
-
 newcode.h2 = handcode(code = newcode.r, excerpts = rs$text, n = 10)
 newcode.t2 = test(code = newcode.h2, kappaThreshold = 0.65)
 summary(newcode.t2)
@@ -31,7 +30,11 @@ newcode.h2 = handcode(code = newcode.h2, excerpts = rs$text, n = 10)
 newcode.t2 = test(code = newcode.h2, kappaThreshold = 0.65)
 summary(newcode.t2)
 
-allcoded = autocode(code = newcode)#.t2)
+# Returns a data.frame 
+allcoded = autocode(x = newcode.t2)
 
-# Convert the coded results to a data.frame
-allcoded.data = as.data.frame(allcoded)
+# Returns back a Code object, with an updated $computerSet 
+allcoded = autocode(x = newcode.t2, simplify = F)
+
+# Convert the Code object directly to a data.frame
+allcoded.data = as.data.frame(newcode.t)
